@@ -2,6 +2,4 @@ from django.conf import settings
 from django.conf.urls.static import static
 from django.urls import include, path, re_path
 
-urlpatterns = [
-]
-
+urlpatterns = []
